@@ -1,35 +1,22 @@
 package XML::GrammarBase::Role::RelaxNG;
-
+$XML::GrammarBase::Role::RelaxNG::VERSION = '0.2.4';
 use strict;
 use warnings;
 
 
-=head1 NAME
-
-XML::GrammarBase::Role::RelaxNG - base class for a RelaxNG validator
-
-=head1 VERSION
-
-Version 0.2.3
-
-=cut
-
 use MooX::Role 'late';
 
 use File::ShareDir qw(dist_dir);
 use XML::LibXML '2.0017';
 
-with ('XML::GrammarBase::Role::DataDir');
+with('XML::GrammarBase::Role::DataDir');
 
-our $VERSION = '0.2.3';
-
-has 'rng_schema_basename' => (isa => 'Str', is => 'rw');
-has '_rng' =>
-(
-    isa => 'XML::LibXML::RelaxNG',
-    is => 'rw',
+has 'rng_schema_basename' => ( isa => 'Str', is => 'rw' );
+has '_rng' => (
+    isa     => 'XML::LibXML::RelaxNG',
+    is      => 'rw',
     default => sub { return shift->_calc_default_rng_schema; },
-    lazy => 1,
+    lazy    => 1,
 );
 
 sub _calc_default_rng_schema
@@ -38,33 +25,28 @@ sub _calc_default_rng_schema
 
     my $rngschema =
         XML::LibXML::RelaxNG->new(
-            location =>
-            $self->dist_path_slot('rng_schema_basename'),
-        );
+        location => $self->dist_path_slot('rng_schema_basename'), );
 
     return $rngschema;
 }
 
 sub rng_validate_dom
 {
-    my ($self, $source_dom) = @_;
+    my ( $self, $source_dom ) = @_;
 
     my $ret_code;
 
-    eval
-    {
-        $ret_code = $self->_rng()->validate($source_dom);
-    };
+    eval { $ret_code = $self->_rng()->validate($source_dom); };
 
-    if (defined($ret_code) && ($ret_code == 0))
+    if ( defined($ret_code) && ( $ret_code == 0 ) )
     {
         # It's OK.
     }
     else
     {
         confess "RelaxNG validation failed [\$ret_code == "
-            . $self->_undefize($ret_code) . " ; $@]"
-            ;
+            . $self->_undefize($ret_code)
+            . " ; $@]";
     }
 
     return;
@@ -85,7 +67,7 @@ sub _calc_parser
 
 sub rng_validate_file
 {
-    my ($self, $filename) = @_;
+    my ( $self, $filename ) = @_;
 
     my $dom = $self->_calc_parser()->parse_file($filename);
 
@@ -94,13 +76,30 @@ sub rng_validate_file
 
 sub rng_validate_string
 {
-    my ($self, $xml_string) = @_;
+    my ( $self, $xml_string ) = @_;
 
     my $dom = $self->_calc_parser()->parse_string($xml_string);
 
     return $self->rng_validate_dom($dom);
 }
 
+
+1;    # End of XML::GrammarBase::RelaxNG::Validate
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+XML::GrammarBase::Role::RelaxNG - base class for a RelaxNG validator
+
+=head1 VERSION
+
+version 0.2.4
+
 =head1 SYNOPSIS
 
     package XML::Grammar::MyGrammar::RelaxNG::Validate;
@@ -121,6 +120,10 @@ sub rng_validate_string
     # Throws an exception on failure.
     $rnger->rng_validate_file("/different-path-to-xml-file.xml");
 
+=head1 VERSION
+
+version 0.2.4
+
 =head1 SLOTS
 
 =head2 module_base
@@ -175,9 +178,6 @@ Please report any bugs or feature requests to C<bug-xml-grammarbase at rt.cpan.o
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-GrammarBase>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -206,10 +206,8 @@ L<http://search.cpan.org/dist/XML-GrammarBase/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Shlomi Fish.
@@ -238,7 +236,132 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/xml-grammarbase/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc XML::GrammarBase::Role::RelaxNG
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/XML-GrammarBase>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/XML-GrammarBase>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-GrammarBase>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/XML-GrammarBase>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/XML-GrammarBase>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/XML-GrammarBase>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/X/XML-GrammarBase>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=XML-GrammarBase>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=XML::GrammarBase>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-xml-grammarbase at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-GrammarBase>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/xml-grammarbase>
+
+  git clone git://github.com/shlomif/xml-grammarbase.git
+
 =cut
-
-1; # End of XML::GrammarBase::RelaxNG::Validate
-
