@@ -1,22 +1,12 @@
 package XML::GrammarBase::Role::XSLT;
-
+$XML::GrammarBase::Role::XSLT::VERSION = '0.2.4';
 use strict;
 use warnings;
 
 
-=head1 NAME
-
-XML::GrammarBase::Role::XSLT - a parameterized role for XSLT conversions.
-
-=head1 VERSION
-
-Version 0.2.3
-
-=cut
-
 use Package::Variant
-    importing => ['MooX::Role' => ['late'],],
-    subs => [ qw(has with) ];
+    importing => [ 'MooX::Role' => ['late'], ],
+    subs      => [qw(has with)];
 
 # use MooX 'late';
 
@@ -25,31 +15,45 @@ use XML::LibXSLT '1.80';
 
 use autodie;
 
-our $VERSION = '0.2.3';
-
-
 sub make_variant
 {
-    my ($class, $target_package, %args) = @_;
+    my ( $class, $target_package, %args ) = @_;
 
     my $output_format = $args{output_format};
 
-    with ('XML::GrammarBase::Role::XSLT::Global');
+    with('XML::GrammarBase::Role::XSLT::Global');
 
-    has "to_${output_format}_xslt_transform_basename"
-        => (isa => 'Str', is => 'rw');
+    has "to_${output_format}_xslt_transform_basename" =>
+        ( isa => 'Str', is => 'rw' );
 
-    has "_to_${output_format}_stylesheet" =>
-    (
-        isa => "XML::LibXSLT::StylesheetWrapper",
-        is => 'rw',
+    has "_to_${output_format}_stylesheet" => (
+        isa     => "XML::LibXSLT::StylesheetWrapper",
+        is      => 'rw',
         default => sub { return shift->_calc_stylesheet($output_format), },
-        lazy => 1,
+        lazy    => 1,
     );
 
     return;
 }
 
+
+
+1;    # End of XML::GrammarBase::RelaxNG::Validate
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+XML::GrammarBase::Role::XSLT - a parameterized role for XSLT conversions.
+
+=head1 VERSION
+
+version 0.2.4
+
 =head1 SYNOPSIS
 
     package XML::Grammar::MyGrammar::ToOtherStuff;
@@ -84,6 +88,10 @@ sub make_variant
         }
     );
 
+=head1 VERSION
+
+version 0.2.4
+
 =head1 PARAMATERS
 
 =head2 output_format
@@ -163,8 +171,6 @@ output_as_chars()) or as C<'bytes'> - using its output_as_bytes() .
 An optional 'xslt_params' parmater allows one to specify a hash of XSLT
 parameters.
 
-=cut
-
 =head2 BUILD
 
 L<Moo> constructor. For internal use.
@@ -218,10 +224,8 @@ L<http://search.cpan.org/dist/XML-GrammarBase/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Shlomi Fish.
@@ -250,7 +254,132 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/xml-grammarbase/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc XML::GrammarBase::Role::XSLT
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/XML-GrammarBase>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/XML-GrammarBase>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-GrammarBase>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/XML-GrammarBase>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/XML-GrammarBase>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/XML-GrammarBase>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/X/XML-GrammarBase>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=XML-GrammarBase>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=XML::GrammarBase>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-xml-grammarbase at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-GrammarBase>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/xml-grammarbase>
+
+  git clone git://github.com/shlomif/xml-grammarbase.git
+
 =cut
-
-1; # End of XML::GrammarBase::RelaxNG::Validate
-
